
*************
Python module
*************

Summary
-------

.. autosummary::

    enstat.scalar
    enstat.static
    enstat.dynamic1d
    enstat.histogram

scalar
------

.. autoclass:: enstat.scalar
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

static
------

.. autoclass:: enstat.static
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

dynamic1d
---------

.. autoclass:: enstat.dynamic1d
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

histogram
---------

.. autoclass:: enstat.histogram
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
